@@ -19,14 +19,8 @@
  */
 
 #include "config.h"
-
 #include "gedit-file-chooser-dialog.h"
-
-#ifdef OS_OSX
-#include "gedit-file-chooser-dialog-osx.h"
-#else
 #include "gedit-file-chooser-dialog-gtk.h"
-#endif
 
 G_DEFINE_INTERFACE (GeditFileChooserDialog, gedit_file_chooser_dialog, G_TYPE_OBJECT)
 
@@ -68,34 +62,17 @@ gedit_file_chooser_dialog_default_init (GeditFileChooserDialogInterface *iface)
 }
 
 GeditFileChooserDialog *
-gedit_file_chooser_dialog_create (const gchar              *title,
-                                  GtkWindow                *parent,
-                                  GeditFileChooserFlags    flags,
-                                  const GtkSourceEncoding *encoding,
-                                  const gchar              *cancel_label,
-                                  GtkResponseType           cancel_response,
-                                  const gchar              *accept_label,
-                                  GtkResponseType           accept_response)
+gedit_file_chooser_dialog_create (const gchar           *title,
+				  GtkWindow             *parent,
+				  GeditFileChooserFlags  flags,
+				  const gchar           *accept_label,
+				  const gchar           *cancel_label)
 {
-#ifdef OS_OSX
-	return gedit_file_chooser_dialog_osx_create (title,
-	                                             parent,
-	                                             flags,
-	                                             encoding,
-	                                             cancel_label,
-	                                             cancel_response,
-	                                             accept_label,
-	                                             accept_response);
-#else
 	return gedit_file_chooser_dialog_gtk_create (title,
 	                                             parent,
 	                                             flags,
-	                                             encoding,
-	                                             cancel_label,
-	                                             cancel_response,
 	                                             accept_label,
-	                                             accept_response);
-#endif
+	                                             cancel_label);
 }
 
 void
@@ -196,19 +173,6 @@ gedit_file_chooser_dialog_set_file (GeditFileChooserDialog *dialog,
 	iface->set_file (dialog, file);
 }
 
-GSList *
-gedit_file_chooser_dialog_get_files (GeditFileChooserDialog *dialog)
-{
-	GeditFileChooserDialogInterface *iface;
-
-	g_return_val_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (dialog), NULL);
-
-	iface = GEDIT_FILE_CHOOSER_DIALOG_GET_IFACE (dialog);
-	g_return_val_if_fail (iface->get_files != NULL, NULL);
-
-	return iface->get_files (dialog);
-}
-
 GFile *
 gedit_file_chooser_dialog_get_file (GeditFileChooserDialog *dialog)
 {
