@@ -4,6 +4,7 @@
  * This file is part of gedit
  *
  * Copyright (C) 2003  Paolo Maggi
+ * Copyright (C) 2019  Canonical LTD
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,27 +20,30 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GEDIT_METADATA_MANAGER_H__
-#define __GEDIT_METADATA_MANAGER_H__
+#ifndef GEDIT_METADATA_MANAGER_H
+#define GEDIT_METADATA_MANAGER_H
 
-#include <glib.h>
 #include <gio/gio.h>
 
 G_BEGIN_DECLS
 
-void		 gedit_metadata_manager_init		(const gchar *metadata_filename);
+#define GEDIT_TYPE_METADATA_MANAGER (gedit_metadata_manager_get_type())
 
-void		 gedit_metadata_manager_shutdown 	(void);
+G_DECLARE_FINAL_TYPE (GeditMetadataManager, gedit_metadata_manager, GEDIT, METADATA_MANAGER, GObject)
 
+GeditMetadataManager *gedit_metadata_manager_new	(const gchar *metadata_filename);
 
-gchar		*gedit_metadata_manager_get 		(GFile       *location,
-					     		 const gchar *key);
-void		 gedit_metadata_manager_set		(GFile       *location,
-							 const gchar *key,
-							 const gchar *value);
+gchar		     *gedit_metadata_manager_get	(GeditMetadataManager *self,
+							 GFile                *location,
+							 const gchar          *key);
+
+void		      gedit_metadata_manager_set	(GeditMetadataManager *self,
+							 GFile                *location,
+							 const gchar          *key,
+							 const gchar          *value);
 
 G_END_DECLS
 
-#endif /* __GEDIT_METADATA_MANAGER_H__ */
+#endif /* GEDIT_METADATA_MANAGER_H */
 
 /* ex:set ts=8 noet: */
