@@ -1,5 +1,4 @@
 /*
- * gedit-status-menu-button.h
  * This file is part of gedit
  *
  * Copyright (C) 2008 - Jesse van den Kieboom
@@ -27,14 +26,16 @@ G_BEGIN_DECLS
 
 #define GEDIT_TYPE_STATUS_MENU_BUTTON (gedit_status_menu_button_get_type ())
 
-G_DECLARE_FINAL_TYPE (GeditStatusMenuButton, gedit_status_menu_button, GEDIT, STATUS_MENU_BUTTON, GtkMenuButton)
+G_DECLARE_FINAL_TYPE (GeditStatusMenuButton, gedit_status_menu_button,
+		      GEDIT, STATUS_MENU_BUTTON,
+		      GtkMenuButton)
 
-GtkWidget *gedit_status_menu_button_new		(void);
+GtkWidget *	gedit_status_menu_button_new		(void);
 
-void gedit_status_menu_button_set_label		(GeditStatusMenuButton *button,
-						 const gchar           *label);
+void		gedit_status_menu_button_set_label	(GeditStatusMenuButton *button,
+							 const gchar           *label);
 
-const gchar *gedit_status_menu_button_get_label (GeditStatusMenuButton *button);
+const gchar *	gedit_status_menu_button_get_label	(GeditStatusMenuButton *button);
 
 G_END_DECLS
 
