@@ -28,13 +28,12 @@
 #  include "gedit-app-win32.h"
 #endif
 
+#include <glib.h>
 #include <locale.h>
 #include <libintl.h>
-#include <tepl/tepl.h>
 
 #include "gedit-dirs.h"
 #include "gedit-debug.h"
-#include "gedit-factory.h"
 #include "gedit-settings.h"
 
 #ifdef G_OS_WIN32
@@ -117,7 +116,6 @@ int
 main (int argc, char *argv[])
 {
 	GType type;
-	GeditFactory *factory;
 	GeditApp *app;
 	gint status;
 
@@ -140,9 +138,6 @@ main (int argc, char *argv[])
 	gedit_dirs_init ();
 
 	setup_i18n ();
-	tepl_init ();
-	factory = gedit_factory_new ();
-	tepl_abstract_factory_set_singleton (TEPL_ABSTRACT_FACTORY (factory));
 
 	app = g_object_new (type,
 	                    "application-id", "org.gnome.gedit",
@@ -167,7 +162,6 @@ main (int argc, char *argv[])
 		                     G_OBJECT (app)->ref_count);
 	}
 
-	tepl_finalize ();
 	gedit_dirs_shutdown ();
 
 #ifdef G_OS_WIN32
