@@ -18,8 +18,8 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GEDIT_FILE_BROWSER_ERROR_H__
-#define __GEDIT_FILE_BROWSER_ERROR_H__
+#ifndef GEDIT_FILE_BROWSER_ERROR_H
+#define GEDIT_FILE_BROWSER_ERROR_H
 
 G_BEGIN_DECLS
 
@@ -37,5 +37,5 @@ typedef enum {
 
 G_END_DECLS
 
-#endif /* __GEDIT_FILE_BROWSER_ERROR_H__ */
+#endif /* GEDIT_FILE_BROWSER_ERROR_H */
 /* ex:set ts=8 noet: */
