@@ -42,7 +42,7 @@ class PythonConsoleConfigWidget(object):
         self._ui = Gtk.Builder()
 
     def configure_widget(self):
-        self._ui.add_objects_from_file(self._ui_path, ["grid"])
+        self._ui.add_from_file(self._ui_path)
 
         self.set_colorbutton_color(self._ui.get_object('colorbutton-command'),
                                    self._settings.get_string(self.CONSOLE_KEY_COMMAND_COLOR))
@@ -57,10 +57,11 @@ class PythonConsoleConfigWidget(object):
 
     @staticmethod
     def set_colorbutton_color(colorbutton, value):
-        color = Gdk.color_parse(value)
+        rgba = Gdk.RGBA()
+        parsed = rgba.parse(value)
 
-        if color is not None:
-            colorbutton.set_color(color)
+        if parsed:
+            colorbutton.set_rgba(rgba)
 
     def on_colorbutton_command_color_set(self, colorbutton):
         self._settings.set_string(self.CONSOLE_KEY_COMMAND_COLOR,
